@@ -105,7 +105,7 @@ class APIData(BaseDataLayer):
         record = self.after_get_object(record, view_kwargs)
         logging.info("record: %s", record)
 
-        obj = models[self.type]["model"](**record)
+        obj = self.model_info[self.type]["model"](**record)
         logging.info("obj: %s", obj)
 
         return obj
@@ -367,7 +367,7 @@ class APIData(BaseDataLayer):
             if property_value is None:
                 continue
             if isinstance(property_value, str):
-                logging.debug("property_value is a string", self)
+                logging.debug("property_value is a string")
 
                 new_property_value = self.repos[property_type].get(property_value)
                 # logging.info("new_value: %s", new_value)
@@ -376,7 +376,7 @@ class APIData(BaseDataLayer):
                 setattr(obj, property_name, new_property_value)
 
             if isinstance(property_value, list):
-                logging.debug("property_value is a list", self)
+                logging.debug("property_value is a list")
 
                 new_property_value = []
                 for list_value in property_value:
@@ -385,11 +385,11 @@ class APIData(BaseDataLayer):
                         value = list_value["$oid"]
                     else:
                         value = list_value
-                    new_obj = self.repos[property_type].get(value)
-                    logging.debug("new_obj: %s", new_obj)
-                    new_value = json.loads(new_obj.to_json())
-                    logging.debug("new_value: %s", new_value)
-                    new_property_value.append(new_value)
+                    # new_obj = self.repos[property_type].get(value)
+                    # logging.debug("new_obj: %s", new_obj)
+                    # new_value = json.loads(new_obj.to_json())
+                    # logging.debug("new_value: %s", new_value)
+                    new_property_value.append({"id": value})
                 logging.debug("new_property_value: %s", new_property_value)
 
                 if isinstance(obj, dict):
@@ -433,7 +433,7 @@ class APIData(BaseDataLayer):
         """
         logging.debug("obj: %s, view_kwargs: %s", obj, view_kwargs)
 
-        this_model = models[self.type]
+        this_model = self.model_info[self.type]
         logging.debug("this_model: %s", this_model)
         properties = this_model.get("properties", {})
         logging.debug("properties: %s", properties)
